set serveroutput on size 1000000
-- This script is a part of 1.0.2.0.1 - 1.0.2.0-TIV-PROSPECT-CISADJ-IF0001
--
-- 1.0.2.0.1 will check the definitions of the 4 entity tables in the Cisco Switch hierarchy
-- to make sure that the column defined for storing the Cisco Switch ID is at least 30
-- characters in size.
--
-- If the columns are already configured as the minimum size or larger, then no changes will
-- be made, this is to avoid errors trying to resize the columns

DECLARE
  vCount       NUMBER;
  vSize        NUMBER;
BEGIN
  -- ENTITY: CiscoSwitch Table:CIS_ENT_SW_CISCOSWITCH Column: CISCO_SWITCH_ID
  SELECT count(table_name) INTO vCount FROM user_tables WHERE table_name = 'CIS_ENT_SW_CISCOSWITCH';
  IF (vCount > 0) THEN
    -- Check existing size to make sure it is not changed adversely
    SELECT data_length INTO vSize FROM user_tab_columns
    WHERE table_name = 'CIS_ENT_SW_CISCOSWITCH'
    AND column_name = 'CISCO_SWITCH_ID';

    -- if the length is appropriate, run the SQL and recompile the trigger which is made invalid.
    IF (vSize < 30) THEN
      run_sql(' ALTER TABLE cis_ent_sw_ciscoswitch MODIFY (cisco_switch_id VARCHAR2(30))');
      run_sql(' ALTER TRIGGER cis_ent_sw_ciscoswitch_biu compile');
    ELSE
      dbms_output.put_line('OK: CIS_ENT_SW_CISCOSWITCH - CISCO_SWITCH_ID is already at min required size');
    END IF;
  ELSE
    dbms_output.put_line('Error: Unable to locate table CIS_ENT_SW_CISCOSWITCH in user_tables');
  END IF;

  -- ENTITY: CPU Table:CIS_ENT_SW_CPU Column: CISCOSWITCH_ID
  SELECT count(table_name) INTO vCount FROM user_tables WHERE table_name = 'CIS_ENT_SW_CPU';
  IF (vCount > 0) THEN
    -- Check existing size to make sure it is not changed adversely
    SELECT data_length INTO vSize FROM user_tab_columns
    WHERE table_name = 'CIS_ENT_SW_CPU'
    AND column_name = 'CISCOSWITCH_ID';

    -- if the length is appropriate, run the SQL and recompile the trigger which is made invalid.
    IF (vSize < 30) THEN
      run_sql(' ALTER TABLE cis_ent_sw_cpu MODIFY (ciscoswitch_id VARCHAR2(30))');
      run_sql(' ALTER TRIGGER cis_ent_sw_cpu_biu compile');
    ELSE
      dbms_output.put_line('OK: CIS_ENT_SW_CPU - CISCOSWITCH_ID is already at min required size');
    END IF;
  ELSE
    dbms_output.put_line('Error: Unable to locate table CIS_ENT_SW_CPU in user_tables');
  END IF;

  -- ENTITY: MemoryPool Table:CIS_ENT_SW_MEMORYPOOL Column: CISCOSWITCH_ID
  SELECT count(table_name) INTO vCount FROM user_tables WHERE table_name = 'CIS_ENT_SW_MEMORYPOOL';
  IF (vCount > 0) THEN
    -- Check existing size to make sure it is not changed adversely
    SELECT data_length INTO vSize FROM user_tab_columns
    WHERE table_name = 'CIS_ENT_SW_MEMORYPOOL'
    AND column_name = 'CISCOSWITCH_ID';

    -- if the length is appropriate, run the SQL and recompile the trigger which is made invalid.
    IF (vSize < 30) THEN
      run_sql(' ALTER TABLE cis_ent_sw_memorypool MODIFY (ciscoswitch_id VARCHAR2(30))');
      run_sql(' ALTER TRIGGER cis_ent_sw_memorypool_biu compile');
    ELSE
      dbms_output.put_line('OK: CIS_ENT_SW_MEMORYPOOL - CISCOSWITCH_ID is already at min required size');
    END IF;
  ELSE
    dbms_output.put_line('Error: Unable to locate table CIS_ENT_SW_MEMORYPOOL in user_tables');
  END IF;

  -- ENTITY: Interface Table:CIS_ENT_SW_INTERFACE Column: CISCOSWITCH_ID
  SELECT count(table_name) INTO vCount FROM user_tables WHERE table_name = 'CIS_ENT_SW_INTERFACE';
  IF (vCount > 0) THEN
    -- Check existing size to make sure it is not changed adversely
    SELECT data_length INTO vSize FROM user_tab_columns
    WHERE table_name = 'CIS_ENT_SW_INTERFACE'
    AND column_name = 'CISCOSWITCH_ID';

    -- if the length is appropriate, run the SQL and recompile the trigger which is made invalid.
    IF (vSize < 30) THEN
      run_sql(' ALTER TABLE cis_ent_sw_interface MODIFY (ciscoswitch_id VARCHAR2(30))');
      run_sql(' ALTER TRIGGER cis_ent_sw_interface_biu compile');
    ELSE
      dbms_output.put_line('OK: CIS_ENT_SW_INTERFACE - CISCOSWITCH_ID is already at min required size');
    END IF;
  ELSE
    dbms_output.put_line('Error: Unable to locate table CIS_ENT_SW_INTERFACE in user_tables');
  END IF;

END;
/
